/******************************************************************************
 * Accept_Command.java - A Player accepts the other player's resignation.
 * $Id: Accept_Command.java,v 1.8 2011/06/09 18:06:46 dick Exp $
 * 
 * jIBS - A Java clone of FIBS
 * Copyright 2002 - Axel Leucht
 * Copyright 2011 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: Accept_Command.java,v $
 * Revision 1.8  2011/06/09 18:06:46  dick
 * Use Player.println() instead of the JibsWriter.
 *
 * Revision 1.7  2011/06/06 03:18:26  dick
 * JibsMessages belongs in n.s.jibs.server, not n.s.jibs.gui
 *
 * Revision 1.6  2011/06/05 05:58:55  dick
 * Output the "accept and win" message before the join-new-game message.
 *
 * Revision 1.5  2011/06/03 19:27:28  dick
 * game.winGame[XO]() just needs the points, not the other parameters.
 *
 * Revision 1.4  2011/06/03 04:15:26  dick
 * Output the "You accept and win" message.
 *
 * Revision 1.3  2011/06/03 00:26:01  dick
 * Show the "pl accepts and wins x points" message.
 *
 * Revision 1.2  2011/05/31 13:02:43  dick
 * Bucko headers.
 *
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is jIBS, <https://sourceforge.net/projects/fibs/>.
 * The Initial Developer of the Original Code is Axel Leucht.
 * 
 */
package net.sourceforge.jibs.command;

import net.sourceforge.jibs.backgammon.BackgammonBoard;
import net.sourceforge.jibs.backgammon.JibsGame;
import net.sourceforge.jibs.server.JibsMessages;
import net.sourceforge.jibs.server.JibsQuestion;
import net.sourceforge.jibs.server.JibsServer;
import net.sourceforge.jibs.server.Player;
import net.sourceforge.jibs.util.DoubleQuestion;
import net.sourceforge.jibs.util.ResignQuestion;

/** A Player accepts the other player's resignation.
 *
 * @author Axel Leucht
 * @author Dick Balaska
 * @version $Revision: 1.8 $ <br> $Date: 2011/06/09 18:06:46 $
 * @see <a href="http://cvs.buckosoft.com/Projects/jIBS/jIBS/src/main/java/net/sourceforge/jibs/command/Accept_Command.java">cvs Accept_Command.java</a>
 */
public class Accept_Command implements JibsCommand {

	@Override
	public boolean execute(JibsServer jibsServer, Player player,
			String strArgs, String[] args) {
		JibsMessages jibsMessages = jibsServer.getJibsMessages();
		JibsGame game = player.getGame();
		JibsQuestion question = player.getQuestion();
		BackgammonBoard board = game.getBackgammonBoard();
		Player opponent = board.getOpponent(player);

		if (question instanceof ResignQuestion) {
			ResignQuestion resignQuestion = (ResignQuestion) question;
			int points = resignQuestion.getResignMode();

			// m_accept_and_win=%0 accepts and wins %1 point%2.
			Object[] obj = { player.getName(), Integer.valueOf(points), points == 1 ? "" : "s"};
			String msg = jibsMessages.convert("m_accept_and_win", obj);
			opponent.println(msg);
			player.show2Watchers(msg);
			opponent.show2Watchers(msg);
			msg = jibsMessages.convert("m_you_accept_and_win", obj);
			player.println(msg);
			if (board.isPlayerX(player)) {
				game.winGameX(points);
			} else {
				game.winGameO(points);
			}
		}

		if (question instanceof DoubleQuestion) {
			DoubleQuestion doubleQuestion = (DoubleQuestion) question;

			// m_accept_double=You accept the double. The cube shows %0.
			Object[] obj = { Integer.valueOf(doubleQuestion.getCubeNew()) };
			String msg = jibsMessages.convert("m_accept_double", obj);

			player.println(msg);
			// m_accept_double_opponent=%0 accepts the double. The cube shows
			// %1.
			obj = new Object[] {
					player.getName(),
					Integer.valueOf(doubleQuestion.getCubeNew())
			};
			msg = jibsMessages.convert("m_accept_double_opponent", obj);
			opponent.println(msg);

			board.setCubeNumber(doubleQuestion.getCubeNew());

			switch (board.getTurn()) {
			case 1: // X accepts double from O
				board.setMayDoubleO(0); // No
				board.setMayDoubleX(1);
				opponent.getClientWorker().executeCmd("roll");

				break;

			case -1: // O acepts double from X
				board.setMayDoubleX(0);
				board.setMayDoubleO(1);
				opponent.getClientWorker().executeCmd("roll");

				break;
			}
		}

		return true;
	}
}
